<?php
/**
 * Article sync function for news_client.
 */

/**
 * Menu callback for admin/config/services/news_client/sync/%.
 */
function news_client_article_sync_page($cached_article_nid) {
  $cached_article = entity_load_single('node', $cached_article_nid);
  $news_service_id = NULL;
  $title = '';
  
  try {
    $ca_wrapper = entity_metadata_wrapper('node', $cached_article);
    $title = $ca_wrapper->title->value();
    $news_service_id = $ca_wrapper->news_client_news_service_nid->value();
  }
  catch (Exception $e) {
    _news_client_entitymetadatawrapper_exception($e);
  }
  
  $build = array();
  
  if (!is_null($news_service_id)) {
    $build['sync_text'] = array(
      '#markup' => '<p>' . t('Would you like to sync %title?', array('%title' => $title)) . '</p>',
    );
    $build['sync_form'] = drupal_get_form('news_client_sync_form', $news_service_id);
  }
  else {
    drupal_set_message(t('Unable to load article with news service id.'));
  }
  
  return $build;
}

/**
 * Form for sync callback.
 */
function  news_client_sync_form($form, &$form_state, $news_service_id) {
  $form = array();
  
  $form['news_service_id'] = array (
    '#type' => 'hidden',
    '#value' => $news_service_id,
  );
  
  $form['actions'] = array(
    '#type' => 'actions',
  );
  
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Sync Cached Article'),
  );
  
  return $form;
}

/**
 * Sync form submit callback.
 */
function news_client_sync_form_submit($form, &$form_state) {
  $news_service_id = $form_state['values']['news_service_id'];
  $site_identifiers = variable_get('news_client_site_identifiers');
  
  $article = _news_client_fetch_article($news_service_id, $site_identifiers);
  
  if (!is_null($article) && !empty($article)) {
    _news_client_cached_article_populate($article);
  }
  else {
    drupal_set_message(t('Failed to retrieve article with id %id from service.', array('%id' => $news_service_id)), 'warning');
  }
  
  $form_state['redirect'] = 'admin/config/services/news_client/cache';
}
